﻿using System.Windows;
using System.Windows.Controls;
using System.Windows.Interactivity;

namespace SilverlightTabStopTest
{
	public class SelectItemOnFocusBehavior : Behavior<FrameworkElement>
	{
		/// <summary>
		/// Gets or sets the target listbox.
		/// </summary>
		public ListBox TargetListbox
		{
			get
			{
				return (ListBox)GetValue(TargetListboxProperty);
			}
			set
			{
				SetValue(TargetListboxProperty, value);
			}
		}

		/// <summary>
		/// A dependency property for the target listbox.
		/// </summary>
		public static readonly DependencyProperty TargetListboxProperty =
			DependencyProperty.Register("TargetListbox",
			typeof(ListBox),
			typeof(SelectItemOnFocusBehavior),
			new PropertyMetadata(null));

		protected override void OnAttached()
		{
			base.OnAttached();
			AssociatedObject.GotFocus += new RoutedEventHandler(AssociatedObject_GotFocus);
		}

		protected override void OnDetaching()
		{
			AssociatedObject.GotFocus -= new RoutedEventHandler(AssociatedObject_GotFocus);
			base.OnDetaching();
		}

		private void AssociatedObject_GotFocus(object sender, RoutedEventArgs e)
		{
			// when the associated object is focused,
			// we try to select the data item (i.e. the data context)
			// in the list box.
			var listBox = TargetListbox;
			if (listBox != null && AssociatedObject.DataContext != null)
			{
				// alternately: just scroll the item into view
				//listBox.ScrollIntoView(AssociatedObject.DataContext);
				listBox.SelectedItem = AssociatedObject.DataContext;
			}
		}
	}
}
